echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

[ -f /etc/profile.d/rustc.sh ] && source /etc/profile.d/rustc.sh

# Required
[[ $(command -v cargo) == "" ]] && echo "Installing rustc" && extension --install rustc && echo "Finished rustc"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[ ! -f /lib/libssh2.so ] && echo "Installing libssh2" && extension --install libssh2 && echo "Finished libssh2"
	#[[ $(command -v sqlite3) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v cargo-capi) == "" ]]; then
	echo "cargo_c" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "cargo_c" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
